@@ -68,8 +68,9 @@ class ThreadedZMQSocketChannel(object):
         evt = Event()
 
         def setup_stream():
+            assert self.socket is not None
             self.stream = zmqstream.ZMQStream(self.socket, self.ioloop)
-            self.stream.on_recv(self._handle_recv)
+            self.stream.on_recv(self._handle_recv)  # type:ignore[arg-type]
             evt.set()
 
         assert self.ioloop is not None
